==> kari-0.23.tar.gz: kari-0.23/parser/staxx.h <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "neve.h"

/* void push_p (neve_in_chains *neve); */
/* void pop_p (neve_in_chains *neve); */
void push_align (neve_in_chains *neve);
void pop_align (neve_in_chains *neve);
void push_font (neve_in_chains *neve, boolean colour, boolean size);
void pop_font  (neve_in_chains *neve);
void push_header (neve_in_chains *neve, int level);
void pop_header (neve_in_chains *neve);
void hack_fstack_size(void);
void hack_fstack_colour(void);
void push_list (neve_in_chains *neve);
void pop_list (neve_in_chains *neve);


/* typedef struct _p_node p_node; */

/* struct _p_node */
/* { */
/*   neve_alignment alignment; */
/*   p_node *next; */
/*   p_node *previous; */
/* }; */


typedef struct _align_node align_node;

struct _align_node
{
  neve_alignment alignment;
  align_node *next;
  align_node *previous;
};



typedef struct _list_node list_node;

struct _list_node
{
  int indent_level;
  int count;
  boolean ol;
  boolean ul;
  boolean dl;
  list_node *next;
  list_node *previous;
};


typedef struct _header_node header_node;

struct _header_node
{
  int level;
  neve_alignment alignment;
  header_node *next;
  header_node *previous;
};


typedef struct _font_node font_node;

struct _font_node
{
  neve_in_chains *node_with_old_values;
  boolean colour_change;
  boolean size_change;
  font_node *next;
  font_node *previous;
};

font_node *font_stack;
header_node *header_stack;
list_node *list_stack;
/* p_node *p_stack; */
align_node *align_stack;

==> kari-0.24.tar.gz: kari-0.24/parser/staxx.h <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "neve.h"

void push_align (neve_alignment alignment);
void pop_align (physical_attribute_types *pattribs);
void push_font (colour_type colour,int size);
void pop_font (physical_attribute_types *pattribs);
void push_header (neve_alignment alignment, int font_level, boolean bold_status);
void pop_header (physical_attribute_types *current_pattribs);
void hack_fstack_size(void);
void hack_fstack_colour(void);
void push_list (logical_attribute_types *lattribs);
void pop_list (logical_attribute_types *lattribs);


typedef struct _align_node align_node;

struct _align_node
{
  neve_alignment alignment;
  align_node *next;
  align_node *previous;
};



typedef struct _list_node list_node;

struct _list_node
{
  int indent_level;
  int count;
  boolean ol;
  boolean ul;
  boolean dl;
  list_node *next;
  list_node *previous;
};


typedef struct _header_node header_node;

struct _header_node
{
  int level;
  neve_alignment alignment;
  boolean bold;
  header_node *next;
  header_node *previous;
};


typedef struct _font_node font_node;

struct _font_node
{
  colour_type colour;
  int size;
  font_node *next;
  font_node *previous;
};

font_node *font_stack;
header_node *header_stack;
list_node *list_stack;
align_node *align_stack;
